Crate math_images_processor

Structs

Functions

  • The most important part of this crate. Takes a DynamicImage from the image crate and returns a processed GrayImage, already within the desired size provided by ImageProcessorConfig.
  • Processes all PNG, JPG, and JPEG files in a directory and saves the processed images in a separate directory. NOTE 1: This uses asynchronous processing, so use with tokio macros in the main function. NOTE 2: Asynchronous processing is almost 7x faster than synchronous processing. For synchronous processing use process_directory_without_async. Final image sizes can be configured via ImageProcessorConfig. For processing a single file use process_image_file. For processing a DynamicImage from the image crate, use directly preprocess_image.
  • Processes a single image file, specified by input_path, and saves the processed image to a new file, specified by output_path. Final image sizes can be configured via ImageProcessorConfig. For processing a directory use process_directory. For processing a DynamicImage from the image crate, use directly preprocess_image.